summaryrefslogtreecommitdiff
path: root/src/theory/quantifiers/sygus/sygus_pbe.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/quantifiers/sygus/sygus_pbe.h')
-rw-r--r--src/theory/quantifiers/sygus/sygus_pbe.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/theory/quantifiers/sygus/sygus_pbe.h b/src/theory/quantifiers/sygus/sygus_pbe.h
index cbd307cab..c63dcf697 100644
--- a/src/theory/quantifiers/sygus/sygus_pbe.h
+++ b/src/theory/quantifiers/sygus/sygus_pbe.h
@@ -19,7 +19,7 @@
#include "theory/quantifiers/sygus/sygus_module.h"
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
namespace quantifiers {
@@ -166,8 +166,8 @@ class SygusPbe : public SygusModule
std::map<Node, Node> d_enum_to_candidate;
};
-} /* namespace CVC4::theory::quantifiers */
-} /* namespace CVC4::theory */
-} /* namespace CVC4 */
+} // namespace quantifiers
+} // namespace theory
+} // namespace CVC5
#endif
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback